# -*- coding: utf-8 -*-
'''
    Torrenter v2 plugin for XBMC/Kodi
    Copyright (C) 2012-2015 Vadim Skorba v1 - DiMartino v2
    http://forum.kodi.tv/showthread.php?tid=214366

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
    
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

import json
import os
import socket
import urllib
from urllib2 import urlopen
import xbmcaddon

import SearcherABC


class Magnetic(SearcherABC.SearcherABC):
    __torrenter_settings__ = xbmcaddon.Addon(id='plugin.video.torrenter')

    ROOT_PATH = os.path.dirname(__file__)
    addon_id = ROOT_PATH.replace('\\', '/').rstrip('/').split('/')[-1]
    __settings__ = xbmcaddon.Addon(id=addon_id)
    __addonpath__ = __settings__.getAddonInfo('path')
    __version__ = __settings__.getAddonInfo('version')
    __plugin__ = __settings__.getAddonInfo('name') + " v." + __version__

    '''
    Weight of source with this searcher provided. Will be multiplied on default weight.
    '''
    sourceWeight = 1

    '''
    Full path to image will shown as source image at result listing
    '''
    searchIcon = os.path.join(__addonpath__, 'icon.png')

    '''
    Flag indicates is this source - magnet links source or not.
    '''

    @property
    def isMagnetLinkSource(self):
        return False

    '''
    Main method should be implemented for search process.
    Receives keyword and have to return dictionary of proper tuples:
    filesList.append((
        int(weight),# Calculated global weight of sources
        int(seeds),# Seeds count
        int(leechers),# Leechers count
        str(size),# Full torrent's content size (e.g. 3.04 GB)
        str(title),# Title (will be shown)
        str(link),# Link to the torrent/magnet
        str(image),# Path to image shown at the list
    ))
    '''

    def __init__(self):
        self.logout()

        if self.timeout_multi == 0:
            socket.setdefaulttimeout(10 + (10 * 120))
        else:
            socket.setdefaulttimeout(10 + (10 * (self.timeout_multi - 1)))

    def search(self, keyword):
        files_list = []
        url = "http://localhost:5005?search=general&title=%s" % urllib.quote_plus(keyword)
        response = urlopen(url, timeout=90).read()
        if "magnets" in response:
            items = json.loads(response)
            for item in items.get("magnets", {}):
                files_list.append((
                    int(int(self.sourceWeight) * item["seeds"]),  # Calculated global weight of sources
                    item["seeds"],  # Seeds count
                    item["peers"],  # Leechers count
                    item["size"],  # Full torrent's content size (e.g. 3.04 GB)
                    item["name"],  # Title (will be shown)
                    item["uri"],  # Link to the torrent/magnet
                    item["icon"],  # Path to image shown at the list
                ))
            return files_list
